# G500_database

Contains code used to generate the **G500 Dataset: Emissions, Energy Use and Climate Targets of Fortune G500 companies in the SBTi and RE100 initiatives** available at https://doi.org/10.4121/16616965
The first version of this code and data was used to produce the Masters thesis by Ivan Ruiz Manuel featured here: https://repository.tudelft.nl/islandora/object/uuid%3A4088c251-9128-4132-99a5-69b336c34478

This code and data are under the Creative Commons CC BY license. Please attribute this work to Ivan Ruiz Manuel and Kornelis Blok.

## Scrapping, parsing and database creation
1. G500 data scrapping
  - fortune_g500.py: obtains Global G500 data from Fortune's website. Not maintaned.
  - g500_scraper.py: supporting module
  - database_operations.py: supporting module
2. HTML CDP questionnaire parser
  - company_operations.py: main script for parsing CDP company data to an Excel file with validation formulas. To run, specify a company name (case sensitive) and filepaths of 5 CDP questionnaire HTML files (order does not matter). Make sure a duplicate file does not exist already in the data/companies folder. Move validated files to the "collected" folder
  - cdp_parser.py: supporting module
3. Pandas database creation (.csv)
  - company_excel_to_pandas.py: will read through all "collected" company files, as well as G500/RE100/SBTi data to create disaggregated databases in the data/ folder.
  
## ICI Database
1. Data manipulation:
  - g500.py: module for parent class with access to all G500 company data. Establishes basic functionality.
  - ici.py: wrapper for all initiatives. Inherits g500
  - sbti.py: holds SBTi members exclusively and has sbti-specific functionality. Inherits ici
  - re100.py: holds RE100 members exclusively and has re100-specific functionality. Inherits ici
2. Plotting:
  - ncc_plots.py: plotting for NCC paper
  - combined_plots: depreciated plots used in the thesis
3. Other:
  - ipcc_scenarios.py: to assist in handling IIASA scenario results
  - unep.py: handles UNEP gap report (2019) data for some plots. Deppreciated.
  - nat_earth.py: to assist in handling Natural Earth country data. Deppreciated.

## Data
- checklist.ods: list of all the companies in the G500, their SBTi and RE100 membership, and whether or not they could be completed.
- companies/completed/: individual files for all the companies participating in an ICI, including Committed members in the SBTi (not featured in the NatCom paper, but included in the thesis)
- Electricity Generation company validation.ods: evaluation of 5 utility companies with targets in the SBTi, done differently from other companies due to data issues in this sector.
- Electricity Generation Net Gen.ods: net generation of electric utilities.
- G500_central.csv: econometric data of G500 companies.
- G500_emissions.csv: GHG Protocol emission scopes of completed companies, collected from CDP questionnarie responses and company reports.
- G500_energy.csv: GHG Protocol energy statistics of completed companies, collected from CDP questionnarie responses and company reports.
- G500_re100.csv: RE100 member target metrics, collected from the RE100 website and RE100 2020 report (see RE100_report_2020.csv and RE100.ods in other/).
- G500_S2MB.csv: energy sourcing data related to Scope 2 Market Based, collected from CDP questionnarie responses and company reports.
- G500_sbti.csv: SBTi membert target metrics, collected from the SBTi database (see SBTi23022020.csv in other/).
- G500_verification: third-party verification per Scope 1 and Scope 2 of member companies.
- mini databases/, old databases/ and other/: other sources used for this study or during intermediate steps in data collection, such as IIASA scenarios, gics sectors, company region, fuzzy string matching, etc.
